@@ -108,11 +108,9 @@ macro_rules! impl_sysvar_get {
 
 #[cfg(test)]
 mod tests {
-    use {
-        super::*,
-        crate::{clock::Epoch, program_error::ProgramError, pubkey::Pubkey},
-        std::{cell::RefCell, rc::Rc},
-    };
+    use super::*;
+    use crate::{clock::Epoch, program_error::ProgramError, pubkey::Pubkey};
+    use std::{cell::RefCell, rc::Rc};
 
     #[repr(C)]
     #[derive(Serialize, Deserialize, Debug, Default, PartialEq)]
